@@ -14,6 +14,11 @@ from flask_appbuilder.charts.views import (ChartView, TimeChartView,
                                            DirectChartView, GroupByChartView,
                                            DirectByChartView)
 from flask_appbuilder.models.group import aggregate_avg, aggregate_count, aggregate_sum
+
+from flask.ext.appbuilder.models.generic import PSSession
+from flask_appbuilder.models.generic.interface import GenericInterface
+from flask_appbuilder.models.generic import PSModel
+
 import logging
 
 logging.basicConfig(format='%(asctime)s:%(levelname)s:%(name)s:%(message)s')
@@ -79,11 +84,31 @@ class FlaskTestCase(unittest.TestCase):
         self.db = SQLA(self.app)
         self.appbuilder = AppBuilder(self.app, self.db.session)
 
+        sess = PSSession()
+
+        class PSView(ModelView):
+            datamodel = GenericInterface(PSModel, sess)
+            base_permissions = ['can_list', 'can_show']
+            list_columns = ['UID', 'C', 'CMD', 'TIME']
+            search_columns = ['UID', 'C', 'CMD']
+
 
         class Model2View(ModelView):
             datamodel = SQLAModel(Model2)
             list_columns = ['field_integer', 'field_float', 'field_string', 'field_method']
 
+            edit_form_query_rel_fields = [('group',
+                                   SQLAModel(Model1, self.db.session),
+                                   [['field_string', FilterEqual, 'G2']]
+                                  )
+                                ]
+
+            add_form_query_rel_fields = [('group',
+                                   SQLAModel(Model1, self.db.session),
+                                   [['field_string', FilterEqual, 'G1']]
+                                  )
+                                ]
+
 
         class Model1View(ModelView):
             datamodel = SQLAModel(Model1)
@@ -174,6 +199,8 @@ class FlaskTestCase(unittest.TestCase):
         self.appbuilder.add_view(Model2TimeChartView, "Model2 Time Chart")
         self.appbuilder.add_view(Model2DirectChartView, "Model2 Direct Chart")
 
+        self.appbuilder.add_view(PSView, "Generic DS PS View", category='PSView')
+
 
     def tearDown(self):
         self.appbuilder = None
@@ -232,7 +259,7 @@ class FlaskTestCase(unittest.TestCase):
         """
             Test views creation and registration
         """
-        eq_(len(self.appbuilder.baseviews), 23)  # current minimal views are 11
+        eq_(len(self.appbuilder.baseviews), 24)  # current minimal views are 11
         
 
     def test_model_creation(self):
@@ -325,6 +352,15 @@ class FlaskTestCase(unittest.TestCase):
         eq_(rv.status_code, 200)
         
 
+    def test_generic_interface(self):
+        """
+            Test Generic Interface for generic-alter datasource
+        """
+        client = self.app.test_client()
+        rv = self.login(client, DEFAULT_ADMIN_USER, DEFAULT_ADMIN_PASSWORD)
+        rv = client.get('/psview/list')
+        data = rv.data.decode('utf-8')
+
 
     def test_model_crud(self):
         """
@@ -357,6 +393,28 @@ class FlaskTestCase(unittest.TestCase):
         model = self.db.session.query(Model1).first()
         eq_(model, None)
 
+
+    def test_query_rel_fields(self):
+        """
+            Test add and edit form related fields filter
+        """
+        client = self.app.test_client()
+        rv = self.login(client, DEFAULT_ADMIN_USER, DEFAULT_ADMIN_PASSWORD)
+        self.insert_data2()
+
+        # Base filter string starts with
+        rv = client.get('/model2view/add?next=%2Fmodel2view%2Flist%2F')
+        data = rv.data.decode('utf-8')
+        ok_('G1' in data)
+        ok_('G2' not in data)
+
+        # Base filter string starts with
+        rv = client.get('/model2view/edit/1')
+        data = rv.data.decode('utf-8')
+        ok_('G2' in data)
+        ok_('G1' not in data)
+
+
     def test_model_list_order(self):
         """
             Test Model order on lists
