@@ -1,11 +1,12 @@
 import logging
 from flask import render_template, flash, redirect, send_file, jsonify, request
 from .actions import action
+from ._compat import as_unicode
+from flask_babelpkg import lazy_gettext
 from .filemanager import uuid_originalname
 from .security.decorators import has_access, permission_name
 from .widgets import FormWidget, GroupFormListWidget, ListMasterWidget
-from .baseviews import expose, BaseView, BaseModelView, BaseCRUDView
-from .models.group import GroupByProcessData
+from .baseviews import expose, BaseView, BaseCRUDView
 from .urltools import *
 
 
@@ -24,7 +25,7 @@ class IndexView(BaseView):
     @expose('/')
     def index(self):
         self.update_redirect()
-        return render_template(self.index_template, appbuilder=self.appbuilder)
+        return self.render_template(self.index_template, appbuilder=self.appbuilder)
 
     @expose('/back')
     def back(self):
@@ -74,7 +75,7 @@ class SimpleFormView(BaseView):
         self.form_get(form)
         widgets = self._get_edit_widget(form=form)
         self.update_redirect()
-        return render_template(self.form_template,
+        return self.render_template(self.form_template,
                                title=self.form_title,
                                widgets=widgets,
                                appbuilder=self.appbuilder
@@ -97,7 +98,7 @@ class SimpleFormView(BaseView):
             return redirect(self.get_redirect())
         else:
             widgets = self._get_edit_widget(form=form)
-            return render_template(
+            return self.render_template(
                 self.form_template,
                 title=self.form_title,
                 widgets=widgets,
@@ -141,7 +142,7 @@ class ModelView(BaseCRUDView):
     def list(self):
 
         widgets = self._list()
-        return render_template(self.list_template,
+        return self.render_template(self.list_template,
                                title=self.list_title,
                                widgets=widgets,
                                appbuilder=self.appbuilder)
@@ -157,7 +158,7 @@ class ModelView(BaseCRUDView):
     def show(self, pk):
 
         widgets = self._show(pk)
-        return render_template(self.show_template,
+        return self.render_template(self.show_template,
                                pk=pk,
                                title=self.show_title,
                                widgets=widgets,
@@ -178,7 +179,7 @@ class ModelView(BaseCRUDView):
         if not widget:
             return redirect(self.get_redirect())
         else:
-            return render_template(self.add_template,
+            return self.render_template(self.add_template,
                                    title=self.add_title,
                                    widgets=widget,
                                    appbuilder=self.appbuilder)
@@ -194,7 +195,7 @@ class ModelView(BaseCRUDView):
         form = self.add_form.refresh()
         form.populate_obj(item)
         widget = self._get_add_widget(form=form, exclude_cols=exclude_cols)
-        return render_template(self.add_template,
+        return self.render_template(self.add_template,
                                    title=self.add_title,
                                    widgets=widget,
                                    appbuilder=self.appbuilder)
@@ -213,7 +214,7 @@ class ModelView(BaseCRUDView):
         if not widgets:
             return redirect(self.get_redirect())
         else:
-            return render_template(self.edit_template,
+            return self.render_template(self.edit_template,
                                    title=self.edit_title,
                                    widgets=widgets,
                                    appbuilder=self.appbuilder,
@@ -276,9 +277,11 @@ class ModelView(BaseCRUDView):
             action = self.actions.get(name)
             return action.func(self.datamodel.get(pk))
         else:
-            flash("Access is Denied %s %s" % (name, self.__class__.__name__), "danger")
+            print("INVALID ACCESS ON {0}".format(self.__class__.__name__))
+            flash(as_unicode(lazy_gettext("Access is Denied")), "danger")
             return redirect('.')
 
+
     @expose('/action_post', methods=['POST'])
     def action_post(self):
         """
@@ -291,7 +294,8 @@ class ModelView(BaseCRUDView):
             items = [self.datamodel.get(pk) for pk in pks]
             return action.func(items)
         else:
-            flash("Access is Denied %s %s" % (name, self.__class__.__name__), "danger")
+            print("INVALID ACCESS ON {0} {1}".format(name, self.__class__.__name__))
+            flash(as_unicode(lazy_gettext("Access is Denied")), "danger")
             return redirect('.')
 
 
@@ -336,7 +340,7 @@ class MasterDetailView(BaseCRUDView):
         else:
             related_views = []
 
-        return render_template(self.list_template,
+        return self.render_template(self.list_template,
                                title=self.list_title,
                                widgets=widgets,
                                related_views=related_views,
@@ -366,7 +370,7 @@ class CompactCRUDMixin(BaseCRUDView):
     @has_access
     def list(self):
         list_widgets = self._list()
-        return render_template(self.list_template,
+        return self.render_template(self.list_template,
                                title=self.list_title,
                                widgets=list_widgets,
                                appbuilder=self.appbuilder)
